@@ -1,16 +1,8 @@
 /*
- * Copyright (C) 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
- * Copyright (C) 2016 Andrius Štikonas <andrius@stikonas.eu>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2016 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "klinebufferedprocess.h"
 
@@ -37,7 +29,7 @@ void KLineBufferedProcessPrivate::_k_receivedStdout()
         m_newlineInStdout = ndata.indexOf(m_lineEnd);
         if (m_newlineInStdout >= 0) {
             m_newlineInStdout += oldBufferSize;
-            emit m_parent->lineReadyStandardOutput();
+            Q_EMIT m_parent->lineReadyStandardOutput();
         }
     }
 }
@@ -52,7 +44,7 @@ void KLineBufferedProcessPrivate::_k_receivedStderr()
         m_newlineInStderr = ndata.indexOf(m_lineEnd);
         if (m_newlineInStderr >= 0) {
             m_newlineInStderr += oldBufferSize;
-            emit m_parent->lineReadyStandardError();
+            Q_EMIT m_parent->lineReadyStandardError();
         }
     }
 }
