@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010, 2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2010-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -46,7 +46,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgDecrypt() override;
+	~KGpgDecrypt() override = default;
 
 	/**
 	 * @brief get decryption result
